@@ -46,10 +46,12 @@ class HttpClient(object):
                     response = requests.request(http_method, cmd_url,
                                                 params=parameters,
                                                 verify=False,
+                                                timeout=5,
                                                 data=payload)
             else:
                 response = requests.request(http_method, cmd_url,
                                             params=parameters,
+                                            timeout=5,
                                             verify=False)
             if 400 < response.status_code < 500:
                 raise KempTechApiException(code=response.status_code)
@@ -180,14 +182,13 @@ class LoadMaster(HttpClient):
         # endpoint is different when attempting to enable the API.
         url = ("https://{user}:{pw}@{ip}"
                "/progs/doconfig/enableapi/set/yes").format(user=self.username,
-                                                            pw=self.password,
-                                                            ip=self.ip_address)
+                                                           pw=self.password,
+                                                           ip=self.ip_address)
         try:
-            response = requests.get(url, verify=False)
+            requests.get(url, verify=False)
+            return True
         except exceptions.RequestException:
-            log.exception("An unknown error occurred with request to %s",
-                          url)
-            raise KempTechApiException(response.text)
+            return False
 
     def stats(self):
         response = self._get('/stats')
